==> istio-client-1.0.0-sources.jar: me/snowdrop/istio/client/internal/operation/RbacConfigOperationImpl.java <==
/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package me.snowdrop.istio.client.internal.operation;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;

import okhttp3.OkHttpClient;

import me.snowdrop.istio.api.rbac.v1alpha1.DoneableRbacConfig;
import me.snowdrop.istio.api.rbac.v1alpha1.RbacConfig;
import me.snowdrop.istio.api.rbac.v1alpha1.RbacConfigList;
import me.snowdrop.istio.api.rbac.v1alpha1.DoneableRbacConfig;

import java.util.Map;
import java.util.TreeMap;


public class RbacConfigOperationImpl extends HasMetadataOperation<RbacConfig, RbacConfigList, DoneableRbacConfig, Resource<RbacConfig, DoneableRbacConfig>> {

  public RbacConfigOperationImpl(OkHttpClient client, Config config, String namespace) {
    this(client, config, "rbac.istio.io", "v1alpha1", namespace, null, true, null, null, false, -1, new TreeMap<String, String>(), new TreeMap<String, String>(), new TreeMap<String, String[]>(), new TreeMap<String, String[]>(), new TreeMap<String, String>());
  }

  public RbacConfigOperationImpl(OkHttpClient client, Config config, String apiVersion, String namespace, String name, Boolean cascading, RbacConfig item, String resourceVersion, Boolean reloadingFromServer, long gracePeriodSeconds, Map<String, String> labels, Map<String, String> labelsNot, Map<String, String[]> labelsIn, Map<String, String[]> labelsNotIn, Map<String, String> fields) {
    super(client, config, "rbac.istio.io", apiVersion, "rbacconfigs", namespace, name, cascading, item, resourceVersion, reloadingFromServer, gracePeriodSeconds, labels, labelsNot, labelsIn, labelsNotIn, fields);
  }

  public RbacConfigOperationImpl(OkHttpClient client, Config config, String apiGroup, String apiVersion, String namespace, String name, Boolean cascading, RbacConfig item, String resourceVersion, Boolean reloadingFromServer, long gracePeriodSeconds, Map<String, String> labels, Map<String, String> labelsNot, Map<String, String[]> labelsIn, Map<String, String[]> labelsNotIn, Map<String, String> fields) {
    super(client, config, apiGroup, apiVersion, "rbacconfigs", namespace, name, cascading, item, resourceVersion, reloadingFromServer, gracePeriodSeconds, labels, labelsNot, labelsIn, labelsNotIn, fields);
  }

  @Override
  public NonNamespaceOperation<RbacConfig, RbacConfigList, DoneableRbacConfig, Resource<RbacConfig, DoneableRbacConfig>> inNamespace(String namespace) {
    return new RbacConfigOperationImpl(client, config, apiGroup, apiVersion, namespace, name, isCascading(), getItem(), getResourceVersion(), isReloadingFromServer(), getGracePeriodSeconds(), getLabels(), getLabelsNot(), getLabelsIn(), getLabelsNotIn(), getFields());
  }

  @Override
  public Resource<RbacConfig, DoneableRbacConfig> withName(String name) {
    return new RbacConfigOperationImpl(client, config, apiGroup, apiVersion, namespace, name, isCascading(), getItem(), getResourceVersion(), isReloadingFromServer(), getGracePeriodSeconds(), getLabels(), getLabelsNot(), getLabelsIn(), getLabelsNotIn(), getFields());
  }
}

==> istio-client-1.1.1-sources.jar: me/snowdrop/istio/client/internal/operation/RbacConfigOperationImpl.java <==
/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package me.snowdrop.istio.client.internal.operation;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import me.snowdrop.istio.api.rbac.v1alpha1.DoneableRbacConfig;
import me.snowdrop.istio.api.rbac.v1alpha1.RbacConfig;
import me.snowdrop.istio.api.rbac.v1alpha1.RbacConfigList;
import me.snowdrop.istio.api.rbac.v1alpha1.DoneableRbacConfig;

import java.util.Map;
import java.util.TreeMap;


public class RbacConfigOperationImpl extends HasMetadataOperation<RbacConfig, RbacConfigList, DoneableRbacConfig, Resource<RbacConfig, DoneableRbacConfig>> {

  public RbacConfigOperationImpl(OkHttpClient client, Config config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config));
  }

  public RbacConfigOperationImpl(OperationContext context) {
    super(context.withApiGroupName("rbac.istio.io")
      .withApiGroupVersion("v1alpha1")
      .withPlural("rbacconfigs"));
    this.type = RbacConfig.class;
    this.listType = RbacConfigList.class;
    this.doneableType = DoneableRbacConfig.class;
}

  public RbacConfigOperationImpl newInstance(OperationContext context) {
    return new RbacConfigOperationImpl(context);
  }
}
